# BSM Event Viewer for Solaris
# Copyright (C) 2000 Kevin Wenchel 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package local_file_dialog;

use Tk;
use Tk::Tree;

#########################
#
#
sub new(){
    my $class = shift;
    $width = shift;
    $height = shift;
    my $self = {};
    bless($self,$class);
    $self->init(@_);
    return $self;
}

#########################
#
#
sub error_dialog(){
 
  my $self = shift; 
  ($text) = @_;
  
  $mw = MainWindow->new;
  $mw->Label(-text=> $text)->grid();
  $mw->Button(-text => "OK",-command => sub{$mw->destroy()})->grid();
  MainLoop;
    
}

#########################
#
#
sub init(){

    $self = shift;
    $mw   = shift;

    $self->{tree} = $mw->ScrlTree(-separator=> '/',
                                  -width=>$width,
                                  -height=>$height,
                                  -scrollbars=>"se");

    $self->{tree}->pack(-expand=>1,
                        -fill=>"both",
                        -pady=>10,
                        -side=>"top");

    $self->{tree}->configure(-selectmode=>"extended");
    $self->{tree}->configure(-opencmd => sub {tree_opendir($self, @_ );});

# Add the root directory the TixTree widget
    $self->tree_adddir( "/" );

# The / directory is added in the "open" mode. The user can open it
# and then browse its subdirectories ...

#    $self->{ok} = $mw->Button(-text=>"OK",
#                              -underline=>0,
#                              -width=>6,
#                              -command => sub { exit } );
#
#    $self->{cancel} = $mw->Button( qw/-text Cancel -underline 0 -width 6/,
#                           -command => sub { exit } );

#    $self->{ok}->pack(-side=>"left",-padx=>10,-pady=>10);
#    $self->{cancel}->pack(-side=>right,-padx=>10,-pady=>10);
   
}

#######################
#
#
sub get_selected_items(){
    my $self = shift;
    my @selection;
    @selection = $self->{tree}->info("selection");
    return(@selection);
}

##############################################
#
#
sub tree_adddir {
    $self = shift;
    my(  $dir ) = @_;

    my $text = $dir;
    $text = (split( "/", $dir ))[-1] unless $text eq "/";

    $self->{tree}->add( $dir,
                        -text => $text, 
                        -image => $self->{tree}->Getimage("folder") );
 
    $self->{tree}->setmode( $dir, -d $dir ? "open" : "none" );
}

##############################################
#
#
sub tree_opendir {
    my $self   = shift;
    my( $dir ) = @_;
  
    if( my @kids = $self->{tree}->infoChildren( $dir ) ) {
	foreach my $kid (@kids) {
            $self->{tree}->show( -entry => $kid );
	}
	return;
    }

    my $image = $self->{tree}->Getimage("file");

    opendir D, $dir or return;
    foreach my $file (sort readdir( D )) {
        next if $file =~ /^\./;
        my $path = "$dir/$file";
        $path = "/$file" if $dir eq "/";
        if( -d $path ) {
	    tree_adddir( $self, $path );
	} else {
            $self->{tree}->add( $path, -text => $file, -image => $image );
	}
    }
    closedir D;
}



1














